Crate yew_toasts

Crate yew_toasts 

A simple and easy toast notifications for Yew.

Structs

ToastCornerContainer
A container for toasts, these holde the toasts and position them.
ToastCornerContainerProps
Props for toast containers, these are used to position the toasts.
ToastData
The data needed to render a toast
ToastProvider
A provider for toasts, renders the toast containers and add a style sheet for the keyframe animations.

Enums

Gravity
The vertical position of the toast
Position
The horizontal position of the toast

Functions

show_toast
Builds and renders a new Toast according to the parameters passed.
show_toast_cb
Reusable Yew Callback that can be reformed and reused betwen different elements.