pub enum Gravity {
Top,
Bottom,
}Expand description
The vertical position of the toast
Variants
Top
The toast will be placed at the top of the screen
Bottom
The toast will be placed at the bottom of the screen