pub enum Position {
Left,
Right,
Center,
}Expand description
The horizontal position of the toast
Variants
Left
The toast will be placed on the left side of the screen
Right
The toast will be placed on the right side of the screen
Center
The toast will be placed in the center of the screen