pub struct ToastData {
pub element: Html,
pub duration: u32,
pub close: bool,
pub gravity: Gravity,
pub position: Position,
pub onclick: Callback<()>,
}Expand description
The data needed to render a toast
Properties
element: The HTML element to render inside the toastduration: The duration of the toast in millisecondsclose: Whether the toast should close when clickedgravity: The vertical position of the toastposition: The horizontal position of the toastonclick: The callback to be called when the toast is clicked
Setting close to true will override the onclick callback.
Fields
element: HtmlThe HTML element to render inside the toast
duration: u32The duration of the toast in milliseconds
close: boolWhether the toast should close when clicked
gravity: GravityThe vertical position of the toast
position: PositionThe horizontal position of the toast
onclick: Callback<()>The callback to be called when the toast is clicked