ToastData

Struct ToastData 

pub struct ToastData {
    pub element: Html,
    pub duration: u32,
    pub close: bool,
    pub gravity: Gravity,
    pub position: Position,
    pub onclick: Callback<()>,
}
The data needed to render a toast

Properties

  • element: The HTML element to render inside the toast
  • duration: The duration of the toast in milliseconds
  • close: Whether the toast should close when clicked
  • gravity: The vertical position of the toast
  • position: The horizontal position of the toast
  • onclick: The callback to be called when the toast is clicked

Setting close to true will override the onclick callback.

Fields

element: Html

The HTML element to render inside the toast

duration: u32

The duration of the toast in milliseconds

close: bool

Whether the toast should close when clicked

gravity: Gravity

The vertical position of the toast

position: Position

The horizontal position of the toast

onclick: Callback<()>

The callback to be called when the toast is clicked